@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0015';
+our $VERSION = '0.0016';
 
 use Moo;
 use strictures 2;
@@ -66,6 +66,9 @@ sub make_setting {
       ['settings'],
       { id => $id },
     )->expand(json => 'settings')->hash->{settings};
+    for my $arg (keys %args) {
+      delete $args{$arg} if $args{$arg} eq '' && !exists $result->{$arg};
+    }
     my $params = { %$result, %args };
     $self->_sqlite->update(
       $self->model,
@@ -101,24 +104,6 @@ sub recall_setting {
 }
 
 
-sub recall_settings {
-  my ($self, %args) = @_;
-  my $name = delete $args{name};
-  croak 'No name given' unless $name;
-  my $sql = q/select id,settings,json_extract(settings, '$.group') as mygroup from /
-    . $self->model
-    . " where name='$name' order by mygroup";
-  my $results = $self->_sqlite->query($sql);
-  my @settings;
-  while (my $next = $results->hash) {
-    push @settings, { $next->{id} => from_json($next->{settings}) };
-    # add the setting name to the settings data
-    $settings[-1]->{ $next->{id} }{name} = $name;
-  }
-  return \@settings;
-}
-
-
 sub recall_all {
   my ($self) = @_;
   my $sql = q/select id,name,settings,json_extract(settings, '$.group') as mygroup from /
@@ -205,7 +190,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0015
+version 0.0016
 
 =head1 SYNOPSIS
 
@@ -227,10 +212,7 @@ version 0.0015
   my $names = $synth->recall_names;
   # [ 'Foo!' ]
 
-  my $settings = $synth->recall_settings(name => $names->[0]);
-  # [ 1 => { etc => '!!!' }, 2 => { etc => '???' } ]
-
-  $settings = $synth->search_settings(etc => '???');
+  my $settings = $synth->search_settings(etc => '???');
   # [ 2 => { etc => '???' } ]
 
   $synth->remove_setting(id => $id1);
@@ -297,8 +279,13 @@ Example:
 
   name: 'My Best Setting!'
   settings:
-    group  parameter control bottom top   value unit is_default
-    filter cutoff    knob    20     20000 200   Hz   true
+    group   parameter control bottom top   value unit is_default
+    filters cutoff    knob    20     20000 200   Hz   true
+
+  name: 'My Other Best Setting!'
+  settings:
+    group parameter control group_to param_to is_default
+    mixer output    patch   filters  vcf-1-in true
 
 =head2 recall_setting
 
@@ -306,12 +293,6 @@ Example:
 
 Return the parameters of a setting for the given B<id>.
 
-=head2 recall_settings
-
-  my $settings = $synth->recall_settings(name => $name);
-
-Return all the settings for a given B<name>.
-
 =head2 recall_all
 
   my $settings = $synth->recall_all;
